@@ -6,7 +6,7 @@ from collections import OrderedDict
 class MLP(nn.Sequential):
 	''' A standard fully connected feed-forward neural network.
 	'''	
-	def __init__(self, config, input_dim, output_dim, nodes_per_layer, num_layers, dropout_rate, batch_norm):
+	def __init__(self, config, input_dim, output_dim, nodes_per_layer, num_layers, dropout_rate, batch_norm, skip_last_act=False):
 		super(MLP, self).__init__()
 		if isinstance(nodes_per_layer, list):
 			num_layers = len(nodes_per_layer)
@@ -17,15 +17,19 @@ class MLP(nn.Sequential):
 		self.predictor = nn.ModuleList()
 		for i in range(num_layers+1):
 			self.predictor.append(nn.Linear(dims[i], dims[i+1]))
-			self.predictor.append(nn.LeakyReLU())
+			
 			if i != num_layers:
+				self.predictor.append(nn.LeakyReLU())
 				if batch_norm:
 					# pass
 					self.predictor.append(nn.BatchNorm1d(dims[i+1]))
 				if dropout_rate != 0:
 					self.predictor.append(nn.Dropout(dropout_rate))
+			else:
+				if not skip_last_act:
+					self.predictor.append(nn.LeakyReLU())
 
-	def forward(self, v):
+	def forward(self, v):    # pragma: no cover
 		# predict
 		v = v.float()
 		for i, layer in enumerate(self.predictor):
@@ -54,21 +58,21 @@ class ConvNet(nn.Sequential):
 			for param in self.predictor.parameters():
 				param.requires_grad = False
 
-			if conv_architecture_last_trained_layer == "last":
+			if conv_architecture_last_trained_layer == "last":    # pragma: no cover
 				pass
-			elif conv_architecture_last_trained_layer == "layer4":
+			elif conv_architecture_last_trained_layer == "layer4":    # pragma: no cover
 				for param in self.predictor[0].avgpool.parameters():
 					param.requires_grad = True
 				for param in self.predictor[0].layer4.parameters():
 					param.requires_grad = True
-			elif conv_architecture_last_trained_layer == "layer3":
+			elif conv_architecture_last_trained_layer == "layer3":    # pragma: no cover
 				for param in self.predictor[0].avgpool.parameters():
 					param.requires_grad = True
 				for param in self.predictor[0].layer4.parameters():
 					param.requires_grad = True
 				for param in self.predictor[0].layer3.parameters():
 					param.requires_grad = True
-			elif conv_architecture_last_trained_layer == "layer2":
+			elif conv_architecture_last_trained_layer == "layer2":    # pragma: no cover
 				for param in self.predictor[0].avgpool.parameters():
 					param.requires_grad = True
 				for param in self.predictor[0].layer4.parameters():
@@ -77,7 +81,7 @@ class ConvNet(nn.Sequential):
 					param.requires_grad = True
 				for param in self.predictor[0].layer2.parameters():
 					param.requires_grad = True
-			elif conv_architecture_last_trained_layer == "layer1":
+			elif conv_architecture_last_trained_layer == "layer1":    # pragma: no cover
 				for param in self.predictor[0].avgpool.parameters():
 					param.requires_grad = True
 				for param in self.predictor[0].layer4.parameters():
@@ -129,8 +133,10 @@ class ConvNet(nn.Sequential):
 				nn.ReLU(inplace=True),
 			)
 			self.predictor[0].classifier = classifier
+		else:
+			raise AttributeError('Unknown name for the convolutional architecture passed. Currenty, the only options available are: '+str(['resnet', 'VGG']))
 
-	def forward(self, v):
+	def forward(self, v):    # pragma: no cover
 		# predict
 		v = v.float()
 		for i, layer in enumerate(self.predictor):
